@@ -5,8 +5,6 @@
 /* Prime Maintainer: Ivan Warren                                     */
 /* Secondary Maintainer: "Fish" (David B. Trout)                     */
 
-// $Id: awstape.c 5587 2009-12-31 15:05:57Z rbowler $
-
 /*-------------------------------------------------------------------*/
 /* This module contains the AWSTAPE emulated tape format support.    */
 /*                                                                   */
@@ -131,14 +129,14 @@ char            pathname[MAX_PATH];     /* file path in host format  */
     hostpath(pathname, dev->filename, sizeof(pathname));
     if(!dev->tdparms.logical_readonly)
     {
-        rc = open (pathname, O_RDWR | O_BINARY);
+        rc = hopen(pathname, O_RDWR | O_BINARY);
     }
 
     /* If file is read-only, attempt to open again */
     if (dev->tdparms.logical_readonly || (rc < 0 && (EROFS == errno || EACCES == errno)))
     {
         dev->readonly = 1;
-        rc = open (pathname, O_RDONLY | O_BINARY);
+        rc = hopen(pathname, O_RDONLY | O_BINARY);
     }
 
     /* Check for successful open */
