@@ -1,8 +1,6 @@
 /* CARDPCH.C    (c) Copyright Roger Bowler, 1999-2009                */
 /*              ESA/390 Card Punch Device Handler                    */
 
-// $Id: cardpch.c 5309 2009-04-04 20:49:13Z rbowler $
-
 /*-------------------------------------------------------------------*/
 /* This module contains device handling functions for emulated       */
 /* System/370 card punch devices.                                    */
@@ -181,7 +179,7 @@ char            pathname[MAX_PATH];     /* file path in host format  */
         {
             open_flags |= O_TRUNC;
         }
-        rc = open (pathname, open_flags,
+        rc = hopen(pathname, open_flags,
                     S_IRUSR | S_IWUSR | S_IRGRP);
         if (rc < 0)
         {
