@@ -1,27 +1,11 @@
 /* CARDRDR.C    (c) Copyright Roger Bowler, 1999-2009                */
 /*              ESA/390 Card Reader Device Handler                   */
 
-// $Id: cardrdr.c 5125 2009-01-23 12:01:44Z bernard $
-
 /*-------------------------------------------------------------------*/
 /* This module contains device handling functions for emulated       */
 /* card reader devices.                                              */
 /*-------------------------------------------------------------------*/
 
-// $Log$
-// Revision 1.47  2007/11/21 22:54:13  fish
-// Use new BEGIN_DEVICE_CLASS_QUERY macro
-//
-// Revision 1.46  2007/06/23 00:04:03  ivan
-// Update copyright notices to include current year (2007)
-//
-// Revision 1.45  2006/12/28 16:13:28  fish
-// Fix PR# readers/104: "HHCRD011E Close error... No Error" in 'cardrdr_close_device' function.
-//
-// Revision 1.44  2006/12/08 09:43:17  jj
-// Add CVS message log
-//
-
 #include "hstdinc.h"
 #include "hercules.h"
 
@@ -464,7 +448,7 @@ char    pathname[MAX_PATH];             /* file path in host format  */
 
     /* Open the device file */
     hostpath(pathname, dev->filename, sizeof(pathname));
-    rc = open (pathname, O_RDONLY | O_BINARY);
+    rc = hopen(pathname, O_RDONLY | O_BINARY);
     if (rc < 0)
     {
         /* Handle open failure */
