@@ -1,30 +1,10 @@
-/* CCKDCDSK.C   (c) Copyright Roger Bowler, 1999-2009                */
-/*       Perform chkdsk for a Compressed CKD Direct Access Storage   */
-/*       Device file.                                                */
-
-// $Id: cckdcdsk.c 5125 2009-01-23 12:01:44Z bernard $
+/* CCKDCDSK.C   (c) Copyright Greg Smith, 2000-2009                  */
+/*              Perform chkdsk for Compressed CKD DASD file          */
 
 /*-------------------------------------------------------------------*/
 /* Perform check function on a compressed ckd file                   */
 /*-------------------------------------------------------------------*/
 
-// $Log$
-// Revision 1.45  2008/11/04 04:50:45  fish
-// Ensure consistent utility startup
-//
-// Revision 1.44  2008/09/09 23:45:27  fish
-// 0 - 4, not 3
-//
-// Revision 1.43  2008/09/04 22:03:15  gsmith
-// Fix 64-bit length problem in cdsk_valid_trk - Tony Harminc
-//
-// Revision 1.42  2007/06/23 00:04:03  ivan
-// Update copyright notices to include current year (2007)
-//
-// Revision 1.41  2006/12/08 09:43:17  jj
-// Add CVS message log
-//
-
 #include "hstdinc.h"
 
 #include "hercules.h"
@@ -85,7 +65,7 @@ DEVBLK         *dev=&devblk;            /* -> DEVBLK                 */
 
         /* open the file */
         hostpath(dev->filename, argv[i], sizeof(dev->filename));
-        dev->fd = open (dev->filename, ro ? O_RDONLY|O_BINARY : O_RDWR|O_BINARY);
+        dev->fd = hopen(dev->filename, ro ? O_RDONLY|O_BINARY : O_RDWR|O_BINARY);
         if (dev->fd < 0)
         {
             cckdumsg (dev, 700, "open error: %s\n", strerror(errno));
