@@ -1,27 +1,10 @@
-/* CCKDCOMP.C   (c) Copyright Roger Bowler, 1999-2009                */
-/*       Perform chkdsk for a Compressed CKD Direct Access Storage   */
-/*       Device file.                                                */
-
-// $Id: cckdcomp.c 5125 2009-01-23 12:01:44Z bernard $
+/* CCKDCOMP.C   (c) Copyright Greg Smith, 2000-2009                  */
+/*              Compress a Compressed CKD DASD file                  */
 
 /*-------------------------------------------------------------------*/
 /* Remove all free space on a compressed ckd file                    */
 /*-------------------------------------------------------------------*/
 
-// $Log$
-// Revision 1.32  2008/11/04 04:50:45  fish
-// Ensure consistent utility startup
-//
-// Revision 1.31  2007/12/01 23:31:57  fish
-// Fix cckdcdsk/cckdcomp/cckdutil no message o/p issue
-//
-// Revision 1.30  2007/06/23 00:04:03  ivan
-// Update copyright notices to include current year (2007)
-//
-// Revision 1.29  2006/12/08 09:43:17  jj
-// Add CVS message log
-//
-
 #include "hstdinc.h"
 
 #include "hercules.h"
@@ -77,7 +60,7 @@ DEVBLK         *dev=&devblk;            /* -> DEVBLK                 */
 
         /* open the file */
         hostpath(dev->filename, argv[i], sizeof(dev->filename));
-        dev->fd = open (dev->filename, O_RDWR|O_BINARY);
+        dev->fd = hopen(dev->filename, O_RDWR|O_BINARY);
         if (dev->fd < 0)
         {
             cckdumsg (dev, 700, "open error: %s\n", strerror(errno));
