@@ -1,23 +1,10 @@
-/* CCKDSWAP.C   (c) Copyright Roger Bowler, 1999-2009                */
-/*       Swap the `endianess' of a compressed CKD file.              */
-
-// $Id: cckdswap.c 5125 2009-01-23 12:01:44Z bernard $
+/* CCKDSWAP.C   (c) Copyright Greg Smith, 2000-2009                  */
+/*              Swap the endianess of a compressed CKD file          */
 
 /*-------------------------------------------------------------------*/
 /* This module changes the `endianess' of a compressed CKD file.     */
 /*-------------------------------------------------------------------*/
 
-// $Log$
-// Revision 1.22  2008/11/04 04:50:45  fish
-// Ensure consistent utility startup
-//
-// Revision 1.21  2007/06/23 00:04:03  ivan
-// Update copyright notices to include current year (2007)
-//
-// Revision 1.20  2006/12/08 09:43:17  jj
-// Add CVS message log
-//
-
 #include "hstdinc.h"
 
 #include "hercules.h"
@@ -75,7 +62,7 @@ DEVBLK         *dev=&devblk;            /* -> DEVBLK                 */
 
         /* open the input file */
         hostpath(dev->filename, argv[i], sizeof(dev->filename));
-        dev->fd = open (dev->filename, O_RDWR|O_BINARY);
+        dev->fd = hopen(dev->filename, O_RDWR|O_BINARY);
         if (dev->fd < 0)
         {
             cckdumsg (dev, 700, "open error: %s\n", strerror(errno));
