@@ -1,54 +1,8 @@
-// ====================================================================
-// Hercules IP Channel-to-Channel Support (CTCI)
-// ====================================================================
-//
-// Copyright    (C) Copyright James A. Pierson, 2002-2009
-//              (C) Copyright "Fish" (David B. Trout), 2002-2009
-//              (C) Copyright Roger Bowler, 2000-2009
-//
-// linux 2.4 modifications (c) Copyright Fritz Elfert, 2001-2009
-//
-// $Id: ctc_ctci.c 5125 2009-01-23 12:01:44Z bernard $
-//
-// $Log$
-// Revision 1.77  2008/11/04 05:56:31  fish
-// Put ensure consistent create_thread ATTR usage change back in
-//
-// Revision 1.76  2008/11/03 15:31:57  rbowler
-// Back out consistent create_thread ATTR modification
-//
-// Revision 1.75  2008/10/18 09:32:21  fish
-// Ensure consistent create_thread ATTR usage
-//
-// Revision 1.74  2008/07/17 07:19:12  fish
-// Fix FCS (Frame Check Sequence) bug in LCS_Write function
-// and other minor bugs.
-//
-// Revision 1.72  2008/07/17 03:30:40  fish
-// CTC/LCS cosmetic-only changes -- part 1
-// (no actual functionality was changed!)
-//
-// Revision 1.71  2008/02/07 00:29:04  rbowler
-// Solaris build support by Jeff Savit
-//
-// Revision 1.70  2008/01/11 21:33:21  fish
-// new 'ctc' command to enable/disable debug option on demand
-//
-// Revision 1.69  2007/11/21 22:54:14  fish
-// Use new BEGIN_DEVICE_CLASS_QUERY macro
-//
-// Revision 1.68  2007/07/29 02:02:44  fish
-// Fix day-1 CTCI/LCS bug found by Vince Weaver [vince@deater.net]
-//
-// Revision 1.67  2007/07/29 00:24:43  fish
-// (comment change only)
-//
-// Revision 1.66  2007/06/23 00:04:05  ivan
-// Update copyright notices to include current year (2007)
-//
-// Revision 1.65  2006/12/08 09:43:19  jj
-// Add CVS message log
-//
+/* CTC_CTCI.C   (c) Copyright Roger Bowler, 2000-2012                */
+/*              (c) Copyright James A. Pierson, 2002-2009            */
+/*              (c) Copyright "Fish" (David B. Trout), 2002-2009     */
+/*              (c) Copyright Fritz Elfert, 2001-2009                */
+/*              Hercules IP Channel-to-Channel Support (CTCI)        */
 
 #include "hstdinc.h"
 
@@ -938,10 +892,16 @@ void  CTCI_Write( DEVBLK* pDEVBLK,   U16   sCount,
 
         if( rc < 0 )
         {
-            logmsg( _("HHCCT047E %4.4X: Error writing to %s: %s\n"),
+            logmsg( _("HHCCT047E %4.4X: Error writing to %s: rc=%d errno=%d %s\n"),
                     pDEVBLK->devnum, pCTCBLK->szTUNDevName,
-                    strerror( errno ) );
+                    rc, errno, strerror(errno));
+        }
 
+        /* Kludge for Ubuntu 10.04 by Martin Truebner */
+        if (rc == -1 && errno == 22) rc = 0;
+
+        if (rc < 0)
+        {
             pDEVBLK->sense[0] = SENSE_EC;
             *pUnitStat        = CSW_CE | CSW_DE | CSW_UC;
             return;
@@ -1020,8 +980,7 @@ static void*  CTCI_ReadThread( PCTCBLK pCTCBLK )
             logmsg( _("HHCCT048E %4.4X: Error reading from %s: %s\n"),
                 pDEVBLK->devnum, pCTCBLK->szTUNDevName,
                 strerror( errno ) );
-            SLEEP(1);           // (purposeful long delay)
-            continue;
+            break;
         }
 
         if( iLength == 0 )      // (probably EINTR; ignore)
