@@ -25,6 +25,9 @@
 /* ------------------------------------------------------------------ */
 #include <string.h>           // [for memset/memcpy]
 #include <stdio.h>            // [for printf]
+#if defined(_MSVC_)
+#pragma warning(disable:4244) // [for win64]
+#endif /*defined(_MSVC_)*/
 
 #define  DECNUMDIGITS  7      // make decNumbers with space for 7
 #include "decNumber.h"        // base number library
