@@ -1,26 +1,11 @@
-////////////////////////////////////////////////////////////////////////////////////
-//         fthreads.c           Fish's WIN32 version of pthreads
+/*  FTHREADS.C  (c) Copyright "Fish" (David B. Trout), 2001-2009     */
+/*              Fish's WIN32 version of pthreads                     */
+
 ////////////////////////////////////////////////////////////////////////////////////
 // (c) Copyright "Fish" (David B. Trout), 2001-2009. Released under the Q Public License
 // (http://www.hercules-390.org/herclic.html) as modifications to Hercules.
 ////////////////////////////////////////////////////////////////////////////////////
 
-// $Id: fthreads.c 5620 2010-02-09 00:24:03Z fish $
-//
-// $Log$
-// Revision 1.30  2007/11/30 14:54:32  jmaynard
-// Changed conmicro.cx to hercules-390.org or conmicro.com, as needed.
-//
-// Revision 1.29  2007/06/23 00:04:10  ivan
-// Update copyright notices to include current year (2007)
-//
-// Revision 1.28  2007/01/10 09:29:45  fish
-// Fix thread naming that was inadvertently broken by my 12/28 fishhang change that introduced use of _beginthreadex
-//
-// Revision 1.27  2006/12/08 09:43:21  jj
-// Add CVS message log
-//
-
 #include "hstdinc.h"
 
 #define _FTHREADS_C_
@@ -93,10 +78,6 @@ static FT_MUTEX*  MallocFT_MUTEX ( )
 
 static BOOL  InitializeFT_MUTEX
 (
-#ifdef FISH_HANG
-    const char*   pszFile,
-    const int     nLine,
-#endif
     FT_MUTEX*     pFT_MUTEX,
     DWORD         dwMutexType
 )
@@ -123,10 +104,6 @@ static BOOL  InitializeFT_MUTEX
 
 static BOOL  UninitializeFT_MUTEX
 (
-#ifdef FISH_HANG
-    const char*  pszFile,
-    const int    nLine,
-#endif
     FT_MUTEX*    pFT_MUTEX
 )
 {
@@ -157,10 +134,6 @@ static FT_COND_VAR*  MallocFT_COND_VAR ( )
 
 static BOOL  InitializeFT_COND_VAR
 (
-#ifdef FISH_HANG
-    const char*   pszFile,
-    const int     nLine,
-#endif
     FT_COND_VAR*  pFT_COND_VAR
 )
 {
@@ -191,10 +164,6 @@ static BOOL  InitializeFT_COND_VAR
 
 static BOOL  UninitializeFT_COND_VAR
 (
-#ifdef FISH_HANG
-    const char*   pszFile,
-    const int     nLine,
-#endif
     FT_COND_VAR*  pFT_COND_VAR
 )
 {
@@ -219,10 +188,6 @@ static BOOL  UninitializeFT_COND_VAR
 
 static BOOL  TryEnterFT_MUTEX
 (
-#ifdef FISH_HANG
-    const char*  pszFile,
-    const int    nLine,
-#endif
     FT_MUTEX*    pFT_MUTEX
 )
 {
@@ -266,10 +231,6 @@ static BOOL  TryEnterFT_MUTEX
 
 static void  EnterFT_MUTEX
 (
-#ifdef FISH_HANG
-    const char*  pszFile,
-    const int    nLine,
-#endif
     FT_MUTEX*    pFT_MUTEX
 )
 {
@@ -305,10 +266,6 @@ static void  EnterFT_MUTEX
 
 static void  LeaveFT_MUTEX
 (
-#ifdef FISH_HANG
-    const char*  pszFile,
-    const int    nLine,
-#endif
     FT_MUTEX*    pFT_MUTEX
 )
 {
@@ -351,10 +308,6 @@ static void  LeaveFT_MUTEX
 
 static int  BeginWait
 (
-#ifdef FISH_HANG
-    const char*       pszFile,
-    const int         nLine,
-#endif
     FT_COND_VAR*      pFT_COND_VAR,
     fthread_mutex_t*  pFTUSER_MUTEX
 )
@@ -452,10 +405,6 @@ static int  BeginWait
         (
             rc = fthread_mutex_unlock
             (
-#ifdef FISH_HANG
-                pszFile,
-                nLine,
-#endif
                 pFTUSER_MUTEX
             )
         )
@@ -469,13 +418,9 @@ static int  BeginWait
         // iable lock before returning our error (i.e. we essentially
         // need to back out what we previously did just above).
 
-#ifdef FISH_HANG
-        logmsg("fthreads: BeginWait: fthread_mutex_unlock failed at %s(%d)! rc=%d\n"
-            ,pszFile ,nLine ,rc );
-#else
         logmsg("fthreads: BeginWait: fthread_mutex_unlock failed! rc=%d\n"
             ,rc );
-#endif
+
         pFT_COND_VAR->nNumWaiting--;    // (de-register wait request)
 
         MyLeaveCriticalSection ( &pFT_COND_VAR->CondVarLock );
@@ -498,10 +443,6 @@ static int  BeginWait
 
 static int  WaitForTransmission
 (
-#ifdef FISH_HANG
-    const char*       pszFile,
-    const int         nLine,
-#endif
     FT_COND_VAR*      pFT_COND_VAR,
     struct timespec*  pTimeTimeout     // (NULL == INFINITE wait)
 )
@@ -608,13 +549,8 @@ static int  WaitForTransmission
     // it or not, actually been completed (although not as they expected it
     // would in all likelihood!)...
 
-#ifdef FISH_HANG
-    logmsg ( "fthreads: WaitForTransmission: MyWaitForSingleObject failed at %s(%d)! dwWaitRetCode=%d (0x%8.8X)\n"
-        ,pszFile ,nLine ,dwWaitRetCode ,dwWaitRetCode );
-#else
     logmsg ( "fthreads: WaitForTransmission: MyWaitForSingleObject failed! dwWaitRetCode=%d (0x%8.8X)\n"
         ,dwWaitRetCode ,dwWaitRetCode );
-#endif
 
     return RC(EFAULT);
 }
@@ -624,10 +560,6 @@ static int  WaitForTransmission
 
 static int  QueueTransmission
 (
-#ifdef FISH_HANG
-    const char*   pszFile,
-    const int     nLine,
-#endif
     FT_COND_VAR*  pFT_COND_VAR,
     BOOL          bXmitType
 )
@@ -683,10 +615,6 @@ static int  QueueTransmission
 
 static void  ReceiveXmission
 (
-#ifdef FISH_HANG
-    const char*   pszFile,
-    const int     nLine,
-#endif
     FT_COND_VAR*  pFT_COND_VAR
 )
 {
@@ -734,10 +662,6 @@ static void  ReceiveXmission
 
 static int  ReturnFromWait
 (
-#ifdef FISH_HANG
-    const char*       pszFile,
-    const int         nLine,
-#endif
     FT_COND_VAR*      pFT_COND_VAR,
     fthread_mutex_t*  pFTUSER_MUTEX,
     int               nRetCode
@@ -768,10 +692,6 @@ static int  ReturnFromWait
         (
             rc = fthread_mutex_lock
             (
-#ifdef FISH_HANG
-                pszFile,
-                nLine,
-#endif
                 pFTUSER_MUTEX
             )
         )
@@ -785,13 +705,8 @@ static int  ReturnFromWait
         // we can do about this; the system is essentially hosed at this point.
         // Just log the fact that something went wrong and return. <shrug>
 
-#ifdef FISH_HANG
-        logmsg("fthreads: ReturnFromWait: fthread_mutex_lock failed at %s(%d)! rc=%d\n"
-            ,pszFile ,nLine ,rc );
-#else
         logmsg("fthreads: ReturnFromWait: fthread_mutex_lock failed! rc=%d\n"
             ,rc );
-#endif
 
         return RC(rc);        // (what went wrong)
     }
@@ -933,10 +848,6 @@ static DWORD  __stdcall  FTWin32ThreadFunc
 DLL_EXPORT
 int  fthread_create
 (
-#ifdef FISH_HANG
-    const char*      pszFile,
-    const int        nLine,
-#endif
     fthread_t*       pdwThreadID,
     fthread_attr_t*  pThreadAttr,
     PFT_THREAD_FUNC  pfnThreadFunc,
@@ -986,11 +897,7 @@ int  fthread_create
 
     if ( !pCallTheirThreadParms )
     {
-#ifdef FISH_HANG
-        logmsg("fthread_create: malloc(FT_CALL_THREAD_PARMS) failed; %s(%d)\n",pszFile,nLine);
-#else
         logmsg("fthread_create: malloc(FT_CALL_THREAD_PARMS) failed\n");
-#endif
         return RC(ENOMEM);      // (out of memory)
     }
 
@@ -999,11 +906,7 @@ int  fthread_create
 
     if ( !pFTHREAD )
     {
-#ifdef FISH_HANG
-        logmsg("fthread_create: malloc(FTHREAD) failed; %s(%d)\n",pszFile,nLine);
-#else
         logmsg("fthread_create: malloc(FTHREAD) failed\n");
-#endif
         free ( pCallTheirThreadParms );
         return RC(ENOMEM);      // (out of memory)
     }
@@ -1029,11 +932,7 @@ int  fthread_create
     if ( !hThread )
     {
         UnlockThreadsList();
-#ifdef FISH_HANG
-        logmsg("fthread_create: MyCreateThread failed; %s(%d)\n",pszFile,nLine);
-#else
         logmsg("fthread_create: MyCreateThread failed\n");
-#endif
         free ( pCallTheirThreadParms );
         free ( pFTHREAD );
         return RC(EAGAIN);      // (unable to obtain required resources)
@@ -1072,10 +971,6 @@ void  fthread_exit
 DLL_EXPORT
 int  fthread_join
 (
-#ifdef FISH_HANG
-    const char*     pszFile,
-    const int       nLine,
-#endif
     fthread_t       dwThreadID,
     void**          pExitVal
 )
@@ -1102,13 +997,12 @@ int  fthread_join
     pFTHREAD->nJoinedCount++;
     hThread = pFTHREAD->hThreadHandle;
 
+    // Wait for thread to exit...
+
     UnlockThreadsList();
-
-    // FishHang doesn't support waiting on thread objects,
-    // only event objects. Thus we do a normal Win32 call here...
-
-    WaitForSingleObject ( hThread, INFINITE ); // (wait for thread exit)
-
+    {
+        WaitForSingleObject ( hThread, INFINITE );
+    }
     LockThreadsList();
 
     if ( pExitVal )
@@ -1387,10 +1281,6 @@ int  fthread_equal
 DLL_EXPORT
 int  fthread_mutex_init
 (
-#ifdef FISH_HANG
-    const char*                 pszFile,
-    const int                   nLine,
-#endif
           fthread_mutex_t*      pFTUSER_MUTEX,
     const fthread_mutexattr_t*  pFT_MUTEX_ATTR
 )
@@ -1411,10 +1301,6 @@ int  fthread_mutex_init
 
     if ( !InitializeFT_MUTEX
     (
-#ifdef FISH_HANG
-        pszFile,
-        nLine,
-#endif
         pFTUSER_MUTEX->hMutex,
         pFT_MUTEX_ATTR ? dwMutexType : FTHREAD_MUTEX_DEFAULT
     ))
@@ -1438,10 +1324,6 @@ int  fthread_mutex_init
 DLL_EXPORT
 int  fthread_mutex_destroy
 (
-#ifdef FISH_HANG
-    const char*       pszFile,
-    const int         nLine,
-#endif
     fthread_mutex_t*  pFTUSER_MUTEX
 )
 {
@@ -1453,10 +1335,6 @@ int  fthread_mutex_destroy
 
     if ( !UninitializeFT_MUTEX
     (
-#ifdef FISH_HANG
-        pszFile,
-        nLine,
-#endif
         pFTUSER_MUTEX->hMutex
     ))
         return RC(EBUSY);       // (still in use)
@@ -1475,10 +1353,6 @@ int  fthread_mutex_destroy
 DLL_EXPORT
 int  fthread_mutex_trylock
 (
-#ifdef FISH_HANG
-    const char*       pszFile,
-    const int         nLine,
-#endif
     fthread_mutex_t*  pFTUSER_MUTEX
 )
 {
@@ -1494,10 +1368,6 @@ int  fthread_mutex_trylock
     (
         !TryEnterFT_MUTEX
         (
-#ifdef FISH_HANG
-            pszFile,
-            nLine,
-#endif
             pFTUSER_MUTEX->hMutex
         )
     )
@@ -1525,10 +1395,6 @@ int  fthread_mutex_trylock
 
     LeaveFT_MUTEX
     (
-#ifdef FISH_HANG
-        pszFile,
-        nLine,
-#endif
         pFTUSER_MUTEX->hMutex
     );
 
@@ -1541,10 +1407,6 @@ int  fthread_mutex_trylock
 DLL_EXPORT
 int  fthread_mutex_lock
 (
-#ifdef FISH_HANG
-    const char*       pszFile,
-    const int         nLine,
-#endif
     fthread_mutex_t*  pFTUSER_MUTEX
 )
 {
@@ -1560,10 +1422,6 @@ int  fthread_mutex_lock
     (
         !TryEnterFT_MUTEX
         (
-#ifdef FISH_HANG
-            pszFile,
-            nLine,
-#endif
             pFTUSER_MUTEX->hMutex
         )
     )
@@ -1574,10 +1432,6 @@ int  fthread_mutex_lock
 
         EnterFT_MUTEX
         (
-#ifdef FISH_HANG
-            pszFile,
-            nLine,
-#endif
             pFTUSER_MUTEX->hMutex
         );
 
@@ -1604,10 +1458,6 @@ int  fthread_mutex_lock
 
     LeaveFT_MUTEX
     (
-#ifdef FISH_HANG
-        pszFile,
-        nLine,
-#endif
         pFTUSER_MUTEX->hMutex
     );
 
@@ -1620,10 +1470,6 @@ int  fthread_mutex_lock
 DLL_EXPORT
 int  fthread_mutex_unlock
 (
-#ifdef FISH_HANG
-    const char*       pszFile,
-    const int         nLine,
-#endif
     fthread_mutex_t*  pFTUSER_MUTEX
 )
 {
@@ -1644,10 +1490,6 @@ int  fthread_mutex_unlock
 
     LeaveFT_MUTEX
     (
-#ifdef FISH_HANG
-        pszFile,
-        nLine,
-#endif
         pFTUSER_MUTEX->hMutex
     );
 
@@ -1660,10 +1502,6 @@ int  fthread_mutex_unlock
 DLL_EXPORT
 int  fthread_cond_init
 (
-#ifdef FISH_HANG
-    const char*      pszFile,
-    const int        nLine,
-#endif
     fthread_cond_t*  pFT_COND_VAR
 )
 {
@@ -1678,10 +1516,6 @@ int  fthread_cond_init
 
     if ( !InitializeFT_COND_VAR
     (
-#ifdef FISH_HANG
-        pszFile,
-        nLine,
-#endif
         pFT_COND_VAR->hCondVar
     ))
     {
@@ -1704,10 +1538,6 @@ int  fthread_cond_init
 DLL_EXPORT
 int  fthread_cond_destroy
 (
-#ifdef FISH_HANG
-    const char*      pszFile,
-    const int        nLine,
-#endif
     fthread_cond_t*  pFT_COND_VAR
 )
 {
@@ -1719,10 +1549,6 @@ int  fthread_cond_destroy
 
     if ( !UninitializeFT_COND_VAR
     (
-#ifdef FISH_HANG
-        pszFile,
-        nLine,
-#endif
         pFT_COND_VAR->hCondVar
     ))
         return RC(EBUSY);       // (still in use)
@@ -1741,10 +1567,6 @@ int  fthread_cond_destroy
 DLL_EXPORT
 int  fthread_cond_signal
 (
-#ifdef FISH_HANG
-    const char*      pszFile,
-    const int        nLine,
-#endif
     fthread_cond_t*  pFT_COND_VAR
 )
 {
@@ -1756,10 +1578,6 @@ int  fthread_cond_signal
 
     return QueueTransmission
     (
-#ifdef FISH_HANG
-        pszFile,
-        nLine,
-#endif
         pFT_COND_VAR->hCondVar,
         FALSE               // (FALSE == not "broadcast")
     );
@@ -1771,10 +1589,6 @@ int  fthread_cond_signal
 DLL_EXPORT
 int  fthread_cond_broadcast
 (
-#ifdef FISH_HANG
-    const char*      pszFile,
-    const int        nLine,
-#endif
     fthread_cond_t*  pFT_COND_VAR
 )
 {
@@ -1786,10 +1600,6 @@ int  fthread_cond_broadcast
 
     return QueueTransmission
     (
-#ifdef FISH_HANG
-        pszFile,
-        nLine,
-#endif
         pFT_COND_VAR->hCondVar,
         TRUE                // (TRUE == "broadcast" type)
     );
@@ -1801,10 +1611,6 @@ int  fthread_cond_broadcast
 DLL_EXPORT
 int  fthread_cond_wait
 (
-#ifdef FISH_HANG
-    const char*       pszFile,
-    const int         nLine,
-#endif
     fthread_cond_t*   pFT_COND_VAR,
     fthread_mutex_t*  pFTUSER_MUTEX
 )
@@ -1835,10 +1641,6 @@ int  fthread_cond_wait
         (
             rc = BeginWait
             (
-#ifdef FISH_HANG
-                pszFile,
-                nLine,
-#endif
                 pFT_COND_VAR -> hCondVar,
                 pFTUSER_MUTEX
             )
@@ -1862,10 +1664,6 @@ int  fthread_cond_wait
 
     rc = WaitForTransmission    // (wait for "signal" or "broadcast"...)
     (
-#ifdef FISH_HANG
-        pszFile,
-        nLine,
-#endif
         pFT_COND_VAR->hCondVar,
         NULL
     );
@@ -1882,10 +1680,6 @@ int  fthread_cond_wait
 
     ReceiveXmission         // (reset transmitter)
     (
-#ifdef FISH_HANG
-        pszFile,
-        nLine,
-#endif
         pFT_COND_VAR->hCondVar
     );
 
@@ -1896,10 +1690,6 @@ int  fthread_cond_wait
 
     return ReturnFromWait
     (
-#ifdef FISH_HANG
-        pszFile,
-        nLine,
-#endif
         pFT_COND_VAR -> hCondVar,
         pFTUSER_MUTEX,
         rc
@@ -1920,10 +1710,6 @@ int  fthread_cond_wait
 DLL_EXPORT
 int  fthread_cond_timedwait
 (
-#ifdef FISH_HANG
-    const char*       pszFile,
-    const int         nLine,
-#endif
     fthread_cond_t*   pFT_COND_VAR,
     fthread_mutex_t*  pFTUSER_MUTEX,
     struct timespec*  pTimeTimeout
@@ -1945,10 +1731,6 @@ int  fthread_cond_timedwait
         (
             rc = BeginWait
             (
-#ifdef FISH_HANG
-                pszFile,
-                nLine,
-#endif
                 pFT_COND_VAR -> hCondVar,
                 pFTUSER_MUTEX
             )
@@ -1959,29 +1741,17 @@ int  fthread_cond_timedwait
 
     rc = WaitForTransmission
     (
-#ifdef FISH_HANG
-        pszFile,
-        nLine,
-#endif
         pFT_COND_VAR->hCondVar,
         pTimeTimeout
     );
 
     ReceiveXmission
     (
-#ifdef FISH_HANG
-        pszFile,
-        nLine,
-#endif
         pFT_COND_VAR->hCondVar
     );
 
     return ReturnFromWait
     (
-#ifdef FISH_HANG
-        pszFile,
-        nLine,
-#endif
         pFT_COND_VAR -> hCondVar,
         pFTUSER_MUTEX,
         rc
