@@ -1,3 +1,6 @@
+/* HETLIB.C    (c) Copyright Leland Lucius, 2000-2009                */
+/*             Library for managing Hercules Emulated Tapes          */
+
 /*
 || ----------------------------------------------------------------------------
 ||
@@ -9,25 +12,6 @@
 || ----------------------------------------------------------------------------
 */
 
-// $Id: hetlib.c 5125 2009-01-23 12:01:44Z bernard $
-//
-// $Log$
-// Revision 1.34  2007/11/21 23:30:41  fish
-// (comment change only)
-//
-// Revision 1.33  2007/07/24 22:36:32  fish
-// Fix tape Synchronize CCW (x'43') to do actual commit
-//
-// Revision 1.32  2007/06/23 00:04:10  ivan
-// Update copyright notices to include current year (2007)
-//
-// Revision 1.31  2007/02/25 21:10:44  fish
-// Fix het_locate to continue on tapemark
-//
-// Revision 1.30  2006/12/08 09:43:26  jj
-// Add CVS message log
-//
-
 #include "hstdinc.h"
 
 #define _HETLIB_C_
@@ -200,7 +184,7 @@ het_open( HETB **hetb, char *filename, int flags )
     omode = "r+b";
     if(!(flags & HETOPEN_READONLY))
     {
-        fd = open( pathname, O_RDWR | O_BINARY | oflags, S_IRUSR | S_IWUSR | S_IRGRP );
+        fd = hopen( pathname, O_RDWR | O_BINARY | oflags, S_IRUSR | S_IWUSR | S_IRGRP );
     }
     if( (flags & HETOPEN_READONLY) || (fd == -1 && (errno == EROFS || errno == EACCES) ) )
     {
@@ -209,7 +193,7 @@ het_open( HETB **hetb, char *filename, int flags )
         */
         omode = "rb";
         thetb->writeprotect = TRUE;
-        fd = open( pathname, O_RDONLY | O_BINARY, S_IRUSR | S_IWUSR | S_IRGRP );
+        fd = hopen( pathname, O_RDONLY | O_BINARY, S_IRUSR | S_IWUSR | S_IRGRP );
     }
 
     /*
