@@ -1,13 +1,5 @@
-/*-------------------------------------------------------------------*/
-/*  HEXTERNS.H            Hercules function prototypes...            */
-/*-------------------------------------------------------------------*/
-
-//      This header auto-#included by 'hercules.h'...
-//
-//      The <config.h> header and other required headers are
-//      presumed to have already been #included ahead of it...
-
-// $Id: hexterns.h 5654 2010-03-07 03:15:17Z fish $
+/* HEXTERNS.H   (c) Copyright Roger Bowler, 1999-2009                */
+/*              Hercules function prototypes                         */
 
 #ifndef _HEXTERNS_H
 #define _HEXTERNS_H
@@ -196,7 +188,7 @@ CONF_DLL_IMPORT int  group_device(DEVBLK *dev, int members);
 int  configure_cpu (int cpu);
 int  deconfigure_cpu (int cpu);
 BLDC_DLL_IMPORT int parse_args (char* p, int maxargc, char** pargv, int* pargc);
-#define MAX_ARGS  12                    /* Max argv[] array size     */
+#define MAX_ARGS  128                   /* Max argv[] array size     */
 int parse_and_attach_devices(const char *devnums,const char *devtype,int ac,char **av);
 CONF_DLL_IMPORT int parse_single_devnum(const char *spec, U16 *lcss, U16 *devnum);
 int parse_single_devnum_silent(const char *spec, U16 *lcss, U16 *devnum);
@@ -226,7 +218,7 @@ HPAN_DLL_IMPORT void update_maxrates_hwm(); // (update high-water-mark values)
 
 /* Functions in module hao.c (Hercules Automatic Operator) */
 #if defined(OPTION_HAO)
-HAO_DLL_IMPORT void hao_initialize(void);       /* initialize hao */
+HAO_DLL_IMPORT int hao_initialize(void);        /* initialize hao */
 HAO_DLL_IMPORT void hao_command(char *command); /* process hao command */
 HAO_DLL_IMPORT void hao_message(char *message); /* process message */
 #endif /* defined(OPTION_HAO) */
@@ -431,4 +423,9 @@ HSYS_DLL_IMPORT int  (*debug_tt32_stats)   (int);
 HSYS_DLL_IMPORT void (*debug_tt32_tracing) (int);
 #endif // defined(OPTION_W32_CTCI)
 
+/* Function in crypto.c */
+#if defined(_FEATURE_MESSAGE_SECURITY_ASSIST)
+void renew_wrapping_keys(void);
+#endif
+
 #endif // _HEXTERNS_H
