@@ -1,34 +1,15 @@
-/* INLINE.H     (c) Copyright Jan Jaeger, 2000-2007                  */
+/* INLINE.H     (c) Copyright Jan Jaeger, 2000-2009                  */
 /*              Inline function definitions                          */
 
-// $Id: inline.h,v 1.49 2007/06/23 00:04:14 ivan Exp $
-
 /* Original author Roger Bowler, 1999                                */
-/* Interpretive Execution - (c) Copyright Jan Jaeger, 1999-2007      */
-/* z/Architecture support - (c) Copyright Jan Jaeger, 1999-2007      */
+/* Interpretive Execution - (c) Copyright Jan Jaeger, 1999-2009      */
+/* z/Architecture support - (c) Copyright Jan Jaeger, 1999-2009      */
 
 /* Storage protection override fix               Jan Jaeger 31/08/00 */
 /* ESAME low-address protection          v208d Roger Bowler 20/01/01 */
 /* ESAME subspace replacement            v208e Roger Bowler 27/01/01 */
 /* Multiply/Divide Logical instructions         Vic Cross 13/02/2001 */
 
-// $Log: inline.h,v $
-// Revision 1.49  2007/06/23 00:04:14  ivan
-// Update copyright notices to include current year (2007)
-//
-// Revision 1.48  2007/03/20 22:28:52  gsmith
-// Use non-concurrent load for fetch_doubleword_absolute on 32bit hosts
-//
-// Revision 1.47  2007/03/07 15:36:56  ivan
-// Fix explicit store protection check for SIE'd guests
-//
-// Revision 1.46  2007/01/04 23:12:04  gsmith
-// remove thunk calls for program_interrupt
-//
-// Revision 1.45  2006/12/08 09:43:28  jj
-// Add CVS message log
-//
-
 // #define INLINE_STORE_FETCH_ADDR_CHECK
 
 #if defined(FEATURE_DUAL_ADDRESS_SPACE)
@@ -54,8 +35,8 @@ _DAT_C_STATIC void ARCH_DEP(invalidate_tlb) (REGS *regs, BYTE mask);
 _DAT_C_STATIC void z900_invalidate_tlb (REGS *regs, BYTE mask);
 #endif
 _DAT_C_STATIC void ARCH_DEP(invalidate_tlbe) (REGS *regs, BYTE *main);
-_DAT_C_STATIC void ARCH_DEP(invalidate_pte) (BYTE ibyte, int r1,
-        int r2, REGS *regs);
+_DAT_C_STATIC void ARCH_DEP(invalidate_pte) (BYTE ibyte, RADR op1,
+        U32 op2, REGS *regs);
 _LOGICAL_C_STATIC BYTE *ARCH_DEP(logical_to_main) (VADR addr, int arn,
         REGS *regs, int acctype, BYTE akey);
 
