@@ -1,8 +1,6 @@
-/* LOGGER.C     (c) Copyright Jan Jaeger, 2003-2007                  */
+/* LOGGER.C     (c) Copyright Jan Jaeger, 2003-2009                  */
 /*              System logger functions                              */
 
-// $Id: logger.c,v 1.54 2008/11/29 21:28:01 rbowler Exp $
-
 /* If standard output or standard error is redirected then the log   */
 /* is written to the redirection.                                    */
 /* If standard output and standard error are both redirected then    */
@@ -13,35 +11,6 @@
 /* Any thread can determine background mode by inspecting stderr     */
 /* for isatty()                                                      */
 
-// $Log: logger.c,v $
-// Revision 1.54  2008/11/29 21:28:01  rbowler
-// Fix warnings C4267 because win64 declares send length as int not size_t
-//
-// Revision 1.53  2008/11/04 05:56:31  fish
-// Put ensure consistent create_thread ATTR usage change back in
-//
-// Revision 1.52  2008/11/03 15:31:54  rbowler
-// Back out consistent create_thread ATTR modification
-//
-// Revision 1.51  2008/10/18 09:32:21  fish
-// Ensure consistent create_thread ATTR usage
-//
-// Revision 1.50  2008/08/23 11:58:52  fish
-// Remove "<pnl...>" color string from most logfile hardcopy o/p
-//
-// Revision 1.49  2007/06/23 00:04:14  ivan
-// Update copyright notices to include current year (2007)
-//
-// Revision 1.48  2007/02/27 21:59:32  kleonard
-// PR# misc/87 startup messages fix completion
-//
-// Revision 1.47  2007/01/31 00:48:03  kleonard
-// Add logopt config statement and panel command
-//
-// Revision 1.46  2006/12/08 09:43:28  jj
-// Add CVS message log
-//
-
 #include "hstdinc.h"
 
 #define _LOGGER_C_
@@ -598,7 +567,7 @@ int   new_hrdcpyfd;
         char pathname[MAX_PATH];
         hostpath(pathname, filename, sizeof(pathname));
 
-        new_hrdcpyfd = open(pathname,
+        new_hrdcpyfd = hopen(pathname,
                 O_WRONLY | O_CREAT | O_TRUNC /* O_SYNC */,
                             S_IRUSR  | S_IWUSR | S_IRGRP);
         if(new_hrdcpyfd < 0)
