@@ -1,25 +1,12 @@
-/* tapesplt.C  (c) Copyright Jay Maynard, 2000-2009                 */
+/* TAPESPLT.C   (c) Copyright Jay Maynard, 2000-2009                 */
 /*              Split AWSTAPE format tape image                      */
 
-// $Id: tapesplt.c 5127 2009-01-23 13:25:01Z bernard $
-
 /*-------------------------------------------------------------------*/
 /* This program reads an AWSTAPE format tape image file and produces */
 /* output files containing pieces of it, controlled by command line  */
 /* options.                                                          */
 /*-------------------------------------------------------------------*/
 
-// $Log$
-// Revision 1.27  2008/11/04 04:50:46  fish
-// Ensure consistent utility startup
-//
-// Revision 1.26  2007/06/23 00:04:18  ivan
-// Update copyright notices to include current year (2007)
-//
-// Revision 1.25  2006/12/08 09:43:31  jj
-// Add CVS message log
-//
-
 #include "hstdinc.h"
 
 #include "hercules.h"
@@ -99,7 +86,7 @@ char            pathname[MAX_PATH];     /* file path in host format  */
 
     /* Open the tape device */
     hostpath(pathname, infilename, sizeof(pathname));
-    infd = open (pathname, O_RDONLY | O_BINARY);
+    infd = hopen(pathname, O_RDONLY | O_BINARY);
     if (infd < 0)
     {
         printf ("tapesplt: error opening input file %s: %s\n",
@@ -119,7 +106,7 @@ char            pathname[MAX_PATH];     /* file path in host format  */
         outfilename = argv[outfilenum];
         printf ("Writing output file %s.\n", outfilename);
         hostpath(pathname, outfilename, sizeof(pathname));
-        outfd = open (pathname, O_WRONLY | O_CREAT | O_BINARY,
+        outfd = hopen(pathname, O_WRONLY | O_CREAT | O_BINARY,
                         S_IRUSR | S_IWUSR | S_IRGRP);
 
         if (outfd < 0)
