@@ -1,10 +1,8 @@
-/* VSTORE.H     (c) Copyright Roger Bowler, 1999-2007                */
+/* VSTORE.H     (c) Copyright Roger Bowler, 1999-2011                */
 /*              ESA/390 Virtual Storage Functions                    */
 
-/* Interpretive Execution - (c) Copyright Jan Jaeger, 1999-2007      */
-/* z/Architecture support - (c) Copyright Jan Jaeger, 1999-2007      */
-
-// $Id: vstore.h,v 1.83 2008/04/02 21:52:19 rbowler Exp $
+/* Interpretive Execution - (c) Copyright Jan Jaeger, 1999-2009      */
+/* z/Architecture support - (c) Copyright Jan Jaeger, 1999-2009      */
 
 /*-------------------------------------------------------------------*/
 /* This module contains various functions which store, fetch, and    */
@@ -34,64 +32,8 @@
 /* wvalidate_operand                                                 */
 /*-------------------------------------------------------------------*/
 
-// $Log: vstore.h,v $
-// Revision 1.83  2008/04/02 21:52:19  rbowler
-// Fix PIC4 when MVCOS operand finishes on page boundary
-//
-// Revision 1.82  2008/03/23 06:13:07  rbowler
-// Add MVCOS instruction (part 3)
-//
-// Revision 1.81  2008/03/23 03:03:45  gsmith
-// 22 Mar 2008 fix unbalanced comment - Peter J Farley III - by Greg
-//
-// Revision 1.80  2008/03/16 00:09:57  rbowler
-// Add MVCOS instruction (part 2)
-//
-// Revision 1.79  2008/02/20 23:47:22  ptl00
-// Fix branch to odd address so pgm old is bumped
-//
-// Revision 1.78  2007/06/23 00:04:19  ivan
-// Update copyright notices to include current year (2007)
-//
-// Revision 1.77  2007/03/13 00:11:14  gsmith
-// Updates to concpy for 64-bit hosts
-//
-// Revision 1.76  2007/03/09 00:54:31  gsmith
-// concpy rework
-//
-// Revision 1.75  2007/03/08 01:27:02  gsmith
-// Remove inline attr from vfetchx/vstorex _full functions
-//
-// Revision 1.74  2007/02/18 16:27:36  gsmith
-// Fix instfetch when instruction crosses 0x800
-//
-// Revision 1.73  2007/01/11 02:44:25  gsmith
-// Temp patch to help messed up gcc v4 optimizations
-//
-// Revision 1.72  2007/01/09 23:19:35  gsmith
-// Tweaks to sloppy fetch
-//
-// Revision 1.71  2007/01/04 23:12:04  gsmith
-// remove thunk calls for program_interrupt
-//
-// Revision 1.70  2007/01/04 01:08:41  gsmith
-// 03 Jan 2007 single_cpu_dw fetch/store patch for ia32
-//
-// Revision 1.69  2007/01/04 00:29:17  gsmith
-// 03 Jan 2007 vstorex patch to vstore2, vstore4, vstore8
-//
-// Revision 1.68  2007/01/03 05:53:34  gsmith
-// 03 Jan 2007 Sloppy fetch - Greg Smith
-//
-// Revision 1.67  2006/12/20 04:26:20  gsmith
-// 19 Dec 2006 ip_all.pat - performance patch - Greg Smith
-//
-// Revision 1.66  2006/12/08 09:43:31  jj
-// Add CVS message log
-//
-
 #define s370_wstorec(_src, _len, _addr, _arn, _regs) \
-        s370_vstorec((_src), (_len), ((_addr) & ADDRESS_MAXWRAP((_regs))), (_arn), (_regs)) 
+        s370_vstorec((_src), (_len), ((_addr) & ADDRESS_MAXWRAP((_regs))), (_arn), (_regs))
 #define s370_wstoreb(_value, _addr, _arn, _regs) \
         s370_vstoreb((_value), ((_addr) & ADDRESS_MAXWRAP((_regs))), (_arn), (_regs))
 #define s370_wstore2(_value, _addr, _arn, _regs) \
@@ -101,7 +43,7 @@
 #define s370_wstore8(_value, _addr, _arn, _regs) \
         s370_vstore8((_value), ((_addr) & ADDRESS_MAXWRAP((_regs))), (_arn), (_regs))
 #define s370_wfetchc(_dest, _len, _addr, _arn, _regs) \
-        s370_vfetchc((_dest), (_len), ((_addr) & ADDRESS_MAXWRAP((_regs))), (_arn), (_regs)) 
+        s370_vfetchc((_dest), (_len), ((_addr) & ADDRESS_MAXWRAP((_regs))), (_arn), (_regs))
 #define s370_wfetchb(_addr, _arn, _regs) \
         s370_vfetchb(((_addr) & ADDRESS_MAXWRAP((_regs))), (_arn), (_regs))
 #define s370_wfetch2(_addr, _arn, _regs) \
@@ -117,7 +59,7 @@
         s370_validate_operand(((_addr) & ADDRESS_MAXWRAP((_regs))), (_arn), (_len), (_acctype), (_regs))
 
 #define s390_wstorec(_src, _len, _addr, _arn, _regs) \
-        s390_vstorec((_src), (_len), ((_addr) & ADDRESS_MAXWRAP((_regs))), (_arn), (_regs)) 
+        s390_vstorec((_src), (_len), ((_addr) & ADDRESS_MAXWRAP((_regs))), (_arn), (_regs))
 #define s390_wstoreb(_value, _addr, _arn, _regs) \
         s390_vstoreb((_value), ((_addr) & ADDRESS_MAXWRAP((_regs))), (_arn), (_regs))
 #define s390_wstore2(_value, _addr, _arn, _regs) \
@@ -127,7 +69,7 @@
 #define s390_wstore8(_value, _addr, _arn, _regs) \
         s390_vstore8((_value), ((_addr) & ADDRESS_MAXWRAP((_regs))), (_arn), (_regs))
 #define s390_wfetchc(_dest, _len, _addr, _arn, _regs) \
-        s390_vfetchc((_dest), (_len), ((_addr) & ADDRESS_MAXWRAP((_regs))), (_arn), (_regs)) 
+        s390_vfetchc((_dest), (_len), ((_addr) & ADDRESS_MAXWRAP((_regs))), (_arn), (_regs))
 #define s390_wfetchb(_addr, _arn, _regs) \
         s390_vfetchb(((_addr) & ADDRESS_MAXWRAP((_regs))), (_arn), (_regs))
 #define s390_wfetch2(_addr, _arn, _regs) \
@@ -143,7 +85,7 @@
         s390_validate_operand(((_addr) & ADDRESS_MAXWRAP((_regs))), (_arn), (_len), (_acctype), (_regs))
 
 #define z900_wstorec(_src, _len, _addr, _arn, _regs) \
-        z900_vstorec((_src), (_len), ((_addr) & ADDRESS_MAXWRAP((_regs))), (_arn), (_regs)) 
+        z900_vstorec((_src), (_len), ((_addr) & ADDRESS_MAXWRAP((_regs))), (_arn), (_regs))
 #define z900_wstoreb(_value, _addr, _arn, _regs) \
         z900_vstoreb((_value), ((_addr) & ADDRESS_MAXWRAP((_regs))), (_arn), (_regs))
 #define z900_wstore2(_value, _addr, _arn, _regs) \
@@ -153,7 +95,7 @@
 #define z900_wstore8(_value, _addr, _arn, _regs) \
         z900_vstore8((_value), ((_addr) & ADDRESS_MAXWRAP((_regs))), (_arn), (_regs))
 #define z900_wfetchc(_dest, _len, _addr, _arn, _regs) \
-        z900_vfetchc((_dest), (_len), ((_addr) & ADDRESS_MAXWRAP((_regs))), (_arn), (_regs)) 
+        z900_vfetchc((_dest), (_len), ((_addr) & ADDRESS_MAXWRAP((_regs))), (_arn), (_regs))
 #define z900_wfetchb(_addr, _arn, _regs) \
         z900_vfetchb(((_addr) & ADDRESS_MAXWRAP((_regs))), (_arn), (_regs))
 #define z900_wfetch2(_addr, _arn, _regs) \
@@ -217,17 +159,18 @@ int     len2;                           /* Length to end of page     */
 
     if ( NOCROSS2K(addr,len) )
     {
-        memcpy(MADDR(addr, arn, regs, ACCTYPE_WRITE, regs->psw.pkey),
+        memcpy(MADDRL(addr, len+1, arn, regs, ACCTYPE_WRITE, regs->psw.pkey),
                src, len + 1);
         ITIMER_UPDATE(addr,len,regs);
     }
     else
     {
         len2 = 0x800 - (addr & 0x7FF);
-        main1 = MADDR(addr, arn, regs, ACCTYPE_WRITE_SKP,
+        main1 = MADDRL(addr, len2, arn, regs, ACCTYPE_WRITE_SKP,
                       regs->psw.pkey);
         sk = regs->dat.storkey;
-        main2 = MADDR((addr + len2) & ADDRESS_MAXWRAP(regs), arn,
+        main2 = MADDRL((addr + len2) & ADDRESS_MAXWRAP(regs),
+                      len+1-len2, arn,
                       regs, ACCTYPE_WRITE, regs->psw.pkey);
         *sk |= (STORKEY_REF | STORKEY_CHANGE);
         memcpy (main1, src, len2);
@@ -297,7 +240,7 @@ _VSTORE_C_STATIC void ARCH_DEP(vstore2) (U16 value, VADR addr, int arn,
     if (likely(!((VADR_L)addr & 1) || ((VADR_L)addr & 0x7FF) != 0x7FF))
     {
         BYTE *mn;
-        mn = MADDR (addr, arn, regs, ACCTYPE_WRITE, regs->psw.pkey);
+        mn = MADDRL (addr, 2, arn, regs, ACCTYPE_WRITE, regs->psw.pkey);
         STORE_HW(mn, value);
         ITIMER_UPDATE(addr,2-1,regs);
     }
@@ -324,12 +267,12 @@ _VSTORE_FULL_C_STATIC void ARCH_DEP(vstore4_full)(U32 value, VADR addr,
 BYTE   *main1, *main2;                  /* Mainstor addresses        */
 BYTE   *sk;                             /* Storage key addresses     */
 int     len;                            /* Length to end of page     */
-BYTE    temp[4];                        /* Copied value              */ 
+BYTE    temp[4];                        /* Copied value              */
 
     len = 0x800 - (addr & 0x7FF);
-    main1 = MADDR(addr, arn, regs, ACCTYPE_WRITE_SKP, regs->psw.pkey);
+    main1 = MADDRL(addr, len, arn, regs, ACCTYPE_WRITE_SKP, regs->psw.pkey);
     sk = regs->dat.storkey;
-    main2 = MADDR((addr + len) & ADDRESS_MAXWRAP(regs), arn, regs,
+    main2 = MADDRL((addr + len) & ADDRESS_MAXWRAP(regs), 4-len, arn, regs,
                   ACCTYPE_WRITE, regs->psw.pkey);
     *sk |= (STORKEY_REF | STORKEY_CHANGE);
     STORE_FW(temp, value);
@@ -346,7 +289,7 @@ _VSTORE_C_STATIC void ARCH_DEP(vstore4) (U32 value, VADR addr, int arn,
     if(likely(!((VADR_L)addr & 0x03)) || (((VADR_L)addr & 0x7ff) <= 0x7fc))
     {
         BYTE *mn;
-        mn = MADDR(addr, arn, regs, ACCTYPE_WRITE, regs->psw.pkey);
+        mn = MADDRL(addr, 4, arn, regs, ACCTYPE_WRITE, regs->psw.pkey);
         STORE_FW(mn, value);
         ITIMER_UPDATE(addr,4-1,regs);
     }
@@ -366,6 +309,9 @@ _VSTORE_C_STATIC void ARCH_DEP(vstore4) (U32 value, VADR addr, int arn,
 /*      A program check may be generated if the logical address      */
 /*      causes an addressing, translation, or protection             */
 /*      exception, and in this case the function does not return.    */
+/*                                                                   */
+/*      NOTE that vstore8_full should only be invoked when a page    */
+/*           boundary IS going to be crossed.                        */
 /*-------------------------------------------------------------------*/
 _VSTORE_FULL_C_STATIC void ARCH_DEP(vstore8_full)(U64 value, VADR addr,
                                               int arn, REGS *regs)
@@ -373,12 +319,12 @@ _VSTORE_FULL_C_STATIC void ARCH_DEP(vstore8_full)(U64 value, VADR addr,
 BYTE   *main1, *main2;                  /* Mainstor addresses        */
 BYTE   *sk;                             /* Storage key addresses     */
 int     len;                            /* Length to end of page     */
-BYTE    temp[8];                        /* Copied value              */ 
+BYTE    temp[8];                        /* Copied value              */
 
     len = 0x800 - (addr & 0x7FF);
-    main1 = MADDR(addr, arn, regs, ACCTYPE_WRITE_SKP, regs->psw.pkey);
+    main1 = MADDRL(addr, len, arn, regs, ACCTYPE_WRITE_SKP, regs->psw.pkey);
     sk = regs->dat.storkey;
-    main2 = MADDR((addr + len) & ADDRESS_MAXWRAP(regs), arn, regs,
+    main2 = MADDRL((addr + len) & ADDRESS_MAXWRAP(regs), 8-len, arn, regs,
                   ACCTYPE_WRITE, regs->psw.pkey);
     *sk |= (STORKEY_REF | STORKEY_CHANGE);
     STORE_DW(temp, value);
@@ -389,21 +335,40 @@ BYTE    temp[8];                        /* Copied value              */
 _VSTORE_C_STATIC void ARCH_DEP(vstore8) (U64 value, VADR addr, int arn,
                                                             REGS *regs)
 {
-    /* Most common case : Aligned & not crossing page boundary */
-    if(likely(!((VADR_L)addr & 0x07)) || (((VADR_L)addr & 0x7ff) <= 0x7f8))
-    {
-        U64 *mn;
-        mn = (U64*)MADDR(addr,arn,regs,ACCTYPE_WRITE,regs->psw.pkey);
 #if defined(OPTION_SINGLE_CPU_DW) && defined(ASSIST_STORE_DW)
+    /* Check alignement. If aligned then we are guaranteed
+       not to cross a page boundary */
+    if(likely(!((VADR_L)addr & 0x07)))
+    {
+        /* Most common case : Aligned */
+        U64 *mn;
+        mn = (U64*)MADDRL(addr,8,arn,regs,ACCTYPE_WRITE,regs->psw.pkey);
         if (regs->cpubit == regs->sysblk->started_mask)
             *mn = CSWAP64(value);
         else
-#endif
         STORE_DW(mn, value);
-        ITIMER_UPDATE(addr,8-1,regs);
     }
     else
-        ARCH_DEP(vstore8_full)(value,addr,arn,regs);
+#endif
+    {
+        /* We're not aligned. So we have to check whether we are
+           crossing a page boundary. This cannot be the same
+           code as above because casting U64 * to a non aligned
+           pointer may break on those architectures mandating
+           strict alignement */
+        if(likely(((VADR_L)addr & 0x7ff) <= 0x7f8))
+        {
+            /* Non aligned but not crossing page boundary */
+            BYTE *mn;
+            mn = MADDRL(addr,8,arn,regs,ACCTYPE_WRITE,regs->psw.pkey);
+            /* invoking STORE_DW ensures endianness correctness */
+            STORE_DW(mn,value);
+        }
+        else
+            /* Crossing page boundary */
+            ARCH_DEP(vstore8_full)(value,addr,arn,regs);
+    }
+    ITIMER_UPDATE(addr,8-1,regs);
 }
 
 /*-------------------------------------------------------------------*/
@@ -587,17 +552,31 @@ BYTE    temp[16];                       /* Copy destination          */
 
 _VSTORE_C_STATIC U64 ARCH_DEP(vfetch8) (VADR addr, int arn, REGS *regs)
 {
-    if(likely(!((VADR_L)addr & 0x07)) || (((VADR_L)addr & 0x7ff) <= 0x7f8 ))
+#if defined(OPTION_SINGLE_CPU_DW) && defined(ASSIST_STORE_DW)
+    if(likely(!((VADR_L)addr & 0x07)))
     {
-    U64 *mn;
+        /* doubleword aligned fetch */
+        U64 *mn;
         ITIMER_SYNC(addr,8-1,regs);
         mn=(U64*)MADDR (addr, arn, regs, ACCTYPE_READ, regs->psw.pkey);
-#if defined(OPTION_SINGLE_CPU_DW) && defined(ASSIST_FETCH_DW)
         if (regs->cpubit == regs->sysblk->started_mask)
             return CSWAP64(*mn);
-#endif
         return fetch_dw(mn);
     }
+    else
+#endif
+    {
+
+        if(likely(((VADR_L)addr & 0x7ff) <= 0x7f8))
+        {
+            /* unaligned, non-crossing doubleword fetch */
+            BYTE *mn;
+            ITIMER_SYNC(addr,8-1,regs);
+            mn=MADDR (addr, arn, regs, ACCTYPE_READ, regs->psw.pkey);
+            return fetch_dw(mn);
+        }
+    }
+    /* page crossing doubleword fetch */
     return ARCH_DEP(vfetch8_full)(addr,arn,regs);
 }
 #endif
@@ -771,8 +750,17 @@ static __inline__ void concpy (REGS *regs, void *d, void *s, int n)
      || (dest <= src  && dest + 8 > src)
      || (src  <= dest && src  + 8 > dest))
     {
-        for ( ; n; n--)
-            *(dest++) = *(src++);
+        /* use memset directly when the copy's effect is to
+           propagate a byte over an area - like in MVC 1(255,2),0(2) */
+        if(dest==src+1)
+        {
+            memset(dest,*src,n);
+        }
+        else
+        {
+            for ( ; n; n--)
+                *(dest++) = *(src++);
+        }
         return;
     }
 
@@ -782,25 +770,40 @@ static __inline__ void concpy (REGS *regs, void *d, void *s, int n)
     for ( ; n2; n2--)
         *(dest++) = *(src++);
 
-#if defined(SIZEOF_LONG) && SIZEOF_LONG == 8 && !defined(OPTION_STRICT_ALIGNMENT)
+#if !defined(OPTION_STRICT_ALIGNMENT) && \
+    ((!defined(_MSVC_) && defined(SIZEOF_LONG)  && SIZEOF_LONG  >= 8) || \
+     ( defined(_MSVC_) && defined(SIZEOF_INT_P) && SIZEOF_INT_P >= 8))
+
+    /* Below for 64-bit BUILDS ONLY, since the below C code
+       does NOT generate atomic 64-bit load/store assembler
+       code sequence compatible with Concurrent Block Update
+       except when building for 64-bit systems...
+    */
     UNREFERENCED(regs);
+
     /* copy 8 bytes at a time */
     for ( ; n >= 8; n -= 8, dest += 8, src += 8)
         *(U64 *)dest = *(U64 *)src;
-#else
+
+#else /* 32-bit builds... */
+
  #if !defined(OPTION_STRICT_ALIGNMENT)
+
     /* copy 4 bytes at a time if only one cpu started */
     if (regs->cpubit == regs->sysblk->started_mask)
         for ( ; n >= 4; n -= 4, dest += 4, src += 4)
             *(U32 *)dest = *(U32 *)src;
     else
- #else
+
+ #else /* defined(OPTION_STRICT_ALIGNMENT) */
     UNREFERENCED(regs);
  #endif
+
     /* else copy 8 bytes at a time concurrently */
         for ( ; n >= 8; n -= 8, dest += 8, src += 8)
             store_dw_noswap(dest,fetch_dw_noswap(src));
-#endif
+
+#endif /* (64-bit builds test...) */
 
     /* copy leftovers */
     for ( ; n; n--)
@@ -868,7 +871,8 @@ int     len2, len3;                     /* Lengths to copy           */
 
     /* Translate addresses of leftmost operand bytes */
     source1 = MADDR (addr2, arn2, regs, ACCTYPE_READ, key2);
-    dest1 = MADDR (addr1, arn1, regs, ACCTYPE_WRITE, key1);
+    dest1 = MADDRL (addr1, len+1, arn1, regs, ACCTYPE_WRITE_SKP, key1);
+    sk1 = regs->dat.storkey;
 
     /* There are several scenarios (in optimal order):
      * (1) dest boundary and source boundary not crossed
@@ -898,13 +902,10 @@ int     len2, len3;                     /* Lengths to copy           */
             concpy (regs, dest1, source1, len2);
             concpy (regs, dest1 + len2, source2, len - len2 + 1);
         }
+        *sk1 |= (STORKEY_REF | STORKEY_CHANGE);
     }
     else
     {
-        dest1 = MADDR (addr1, arn1, regs, ACCTYPE_WRITE_SKP, key1);
-        sk1 = regs->dat.storkey;
-        source1 = MADDR (addr2, arn2, regs, ACCTYPE_READ, key2);
-
         /* First operand crosses a boundary */
         len2 = 0x800 - (addr1 & 0x7FF);
         dest2 = MADDR ((addr1 + len2) & ADDRESS_MAXWRAP(regs),
@@ -944,6 +945,8 @@ int     len2, len3;                     /* Lengths to copy           */
                 concpy (regs, dest2, source2 + len2 - len3, len - len2 + 1);
             }
         }
+        *sk1 |= (STORKEY_REF | STORKEY_CHANGE);
+        *sk2 |= (STORKEY_REF | STORKEY_CHANGE);
     }
     ITIMER_UPDATE(addr1,len,regs);
 
@@ -1007,7 +1010,7 @@ int     len1, len2, len3;               /* Work areas for lengths    */
 
     /* Translate addresses of leftmost operand bytes */
     main2 = MADDR (addr2, space2, regs, ACCTYPE_READ, key2);
-    main1 = MADDR (addr1, space1, regs, ACCTYPE_WRITE, key1);
+    main1 = MADDRL (addr1, len, space1, regs, ACCTYPE_WRITE, key1);
 
     /* Copy the largest chunks which do not cross a 2K
        boundary of either source or destination operand */
